/*
 * NASPRO - The NASPRO Architecture for Sound Processing
 * A collection of bridges to LV2
 * DSSI bridge
 *
 * Copyright (C) 2007-2011 NASPRO bridges development team
 *
 * See the COPYING file for license conditions.
 */

NACORE_PRIVATE void
plugin_load(nabrit_pluglib pluglib, const DSSI_Descriptor *desc);

NACORE_PRIVATE void
plugin_unload(void *value, void *opaque);
